@@ -15,15 +15,11 @@
 
 **********************************************************************/
 
-
 #ifndef ___MSEQUENCE_H___
 #define ___MSEQUENCE_H___
 
-#include "task.h"
+#include "thread.h"
 
-#ifdef __cplusplus
-extern "C" {
-#endif
 #define MS_INFO_NUM 100
 
 typedef struct ms_info
@@ -38,12 +34,9 @@ typedef struct ms_info
 void init_msequence();
 void ms_loop();
 void ms_loop_proc();
-//int ms_do(int (*func)(void*), void * arg, char str[]);
-#define get_userinterface_tid()	(0)
+int ms_do(int (*func)(void*), void * arg,int,const char str[]);
+int get_userinterface_tid();
+//void er_panic(char*);
 
-
-#ifdef __cplusplus
-}
-#endif
 #endif
 
