@@ -30,7 +30,9 @@
 
 /*
 #define DRAW_DEBUG
+#define DRAW_DEBUG_1
 */
+
 #define SC_OFFSET	0
 #define SC_RATE		0.6
 
@@ -90,6 +92,10 @@ void _digging_matrix(
 	GB_RECT * r,
 	int lev,
 	DM_TIME_LIST * tl);
+void
+set_handle_dm_list(DRAW_MATRIX ** lst);
+void
+reset_handle_dm_list(DRAW_MATRIX ** lst);
 
 
 SEM dm_lock;
@@ -132,11 +138,12 @@ void dm_loading_task2(TKEY);
 void gc_dm_t();
 void gc_get_dm_t();
 
-
+/*
 MEM_PURGE_TBL dm_mpt = {
 	dm_last_access,
 	dm_gc_obj
 };
+*/
 
 void
 init_draw_matrix()
@@ -186,7 +193,7 @@ void indicate_md_by_large();
 /*
 new_tick(print_mem_size,1);
 */
-	set_mem_purge(&dm_mpt);
+//	set_mem_purge(&dm_mpt);
 }
 
 void
@@ -213,6 +220,8 @@ void gc_gb_sexp();
 void
 dm_gc_obj()
 {
+
+ss_printf("dm_gc_obj\n");
 	lock_task(dm_lock);
 	scan_flag = 1;
 	wakeup_task((int)&dm_h);
@@ -331,24 +340,38 @@ DM_TIME_LIST * tl;
 	}
 }
 
+void
+count_handle()
+{
+DRAW_MATRIX * d;
+int cnt,total;
+	d = R_NEXT(DRAW_MATRIX *,&dm_h);
+	cnt = total = 0;
+	for ( ; d != (DRAW_MATRIX*)&dm_h ; d = R_NEXT(DRAW_MATRIX*,&d->h) ) {
+		if ( d->flags & DMF_HANDLING )
+			cnt ++;
+		total ++;
+	}
+	ss_printf("HANDLE %i %i\n",cnt,total);
+}
+
 void
 dm_resource_scan()
 {
 int i,j;
-DRAW_MATRIX * d;
+DRAW_MATRIX * d,*d2;
 DRAW_MATRIX * d_st;
+INTEGER64 tim;
 
-int target;
 
-	target = dm_nos * 0.75;
-	if ( target <= 0 )
-		target = 1;
-	log_printf(LOG_MESSAGE,LOG_LAYER_GB,0,"scan %i\n",target);
 	for ( ; check_queue(&pipe1,0,0) ; )
 		sleep_sec(1);
 
 	lock_task(dm_lock);
+/*
+count_handle();
 	_aboat_dm_loading(1);
+*/
 	for ( ; dg_write_lock ; ) {
 		sleep_task((int)&dg_write_lock,dm_lock);
 		lock_task(dm_lock);
@@ -356,50 +379,46 @@ int target;
 	dg_write_lock = 1;
 	unlock_task(dm_lock,"scan");
 
-	for ( ; dm_nos > target ; ) {
+
+	tim = get_xltime();
+	d_st = d = R_PREV(DRAW_MATRIX *,&dm_h);
+	for ( ; ; ) {
 		lock_task(dm_lock);
-		d_st = d = R_PREV(DRAW_MATRIX *,&dm_h);
-		for ( ; ; ) {
-			if ( d == (DRAW_MATRIX*)&dm_h ) {
-				d = R_PREV(DRAW_MATRIX*,&dm_h);
-				if ( d == d_st ) {
-					log_printf(LOG_WARNING,LOG_LAYER_GB,0,
-							"UNRESOLVE SCAN DM 1\n");
-					goto end;
-				}
-			}
-			if ( d->up == 0 )
-				goto no;
-
-			for ( i = 0 ; i < DM_DIM ; i ++ )
-				for ( j = 0 ; j < DM_DIM ; j ++ ) {
-					if ( d->m[i][j] == 0 )
-						continue;
-					goto no;
-				}
-			*d->up = 0;
-
-			DELETE_RING(&d->h);
-			unlock_task(dm_lock,"scan");
-
-
-			scan_dm_point_list(d);
-			d_f_ree(d);
-			touch_obj_mem(-sizeof(*d));
-			dm_nos --;
+		if ( d == (DRAW_MATRIX*)&dm_h )
 			break;
-		no:
-			d = R_PREV(DRAW_MATRIX*,&d->h);
-			if ( d == d_st ) {
-				log_printf(LOG_WARNING,LOG_LAYER_GB,0,
-						"UNRESOLVE SCAN DM 2\n");
-				goto end;
-			}
+		if ( tim - d->access < DM_ACCESS_LIFE_TIME )
+			break;
+		d2 = R_PREV(DRAW_MATRIX *,&d->h);
+		if ( d->up == 0 ) {
+			unlock_task(dm_lock,"scan");
+			goto no;
 		}
+		if ( d->flags & DMF_HANDLING ) {
+			unlock_task(dm_lock,"scan");
+			goto no;
+		}
+		for ( i = 0 ; i < DM_DIM ; i ++ )
+			for ( j = 0 ; j < DM_DIM ; j ++ ) {
+				if ( d->m[i][j] == 0 )
+					continue;
+				unlock_task(dm_lock,"scan");
+				goto no;
+			}
+		*d->up = 0;
+		d->flags |= DMF_DELETE;
+		DELETE_RING(&d->h);
+		unlock_task(dm_lock,"scan");
+
+
+		scan_dm_point_list(d);
+		d_f_ree(d);
+		touch_obj_mem(-sizeof(*d));
+		dm_nos --;
+		
+	no:
+		d = d2;
 	}
 
-	lock_task(dm_lock);
-end:
 	dg_write_lock = 0;
 	wakeup_task((int)&dg_write_lock);
 	unlock_task(dm_lock,"scan");
@@ -444,6 +463,8 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 		type = n->type;
 		dbuf = n->dbuf;
 
+		reset_handle_dm_list(&n->dm_list[0]);
+
 		d_f_ree(n->h.key);
 		d_f_ree(n);
 		lock_task(dm_lock);
@@ -456,6 +477,11 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 		unlock_task(dm_lock,"dm_loading_task1");
 
 		if ( type == DGT_PDB ) {
+#ifdef DRAW_DEBUG
+ss_printf("DGT_PDB START = ");
+print_sexp(s_stdout,ld,PF_RAW_DISABLE);
+ss_printf("\n");
+#endif
 			for ( ; get_type(ld) == XLT_PAIR ; ld = cdr(ld) ) {
 				ret = _dgb_p2d_trailer(r,car(ld));
 				if ( get_type(ret) == XLT_ERROR ) {
@@ -481,7 +507,7 @@ extern XLISP_ENV * gv_resource_env[RT_MAX];
 			unlock_pdb_lock(r);
 #ifdef DRAW_DEBUG
 ss_printf("START = ");
-print_sexp(s_stdout,ld,0);
+print_sexp(s_stdout,ld,PF_RAW_DISABLE);
 ss_printf("\n");
 #endif
 			for ( ; get_type(ld) == XLT_PAIR &&
@@ -493,7 +519,7 @@ ss_printf("\n");
 			else {
 #ifdef DRAW_DEBUG
 ss_printf("END = ");
-print_sexp(s_stdout,ld,0);
+print_sexp(s_stdout,ld,PF_RAW_DISABLE);
 ss_printf("\n");
 #endif
 				ret = eval(e,car(ld));
@@ -524,8 +550,10 @@ ss_printf("\n");
 	}
 	close_self_interpreter();
 	release_qkey(&pipe2,key);
+	d_f_ree(key);
 }
 
+
 void
 dm_loading_task2(TKEY _d)
 {
@@ -583,6 +611,17 @@ D_BUF dbuf;
 		for ( pp = ld ; get_type(pp) == XLT_PAIR ; pp = cdr(pp) );
 
 
+#ifdef DRAW_DEBUG_1
+ss_printf("DGT_PDB GET = ");
+print_sexp(s_stdout,ld,PF_RAW_DISABLE);
+ss_printf("\n");
+if ( ld && ld->h.file ) {
+ss_printf("STREAM %x\n",ld->h.file->st);
+}
+else {
+ss_printf("STREAM - \n");
+}
+#endif
 		lock_task(dm_lock);
 		tl->aboat_target = 0;
 		wakeup_task((int)&tl->aboat_target);
@@ -591,14 +630,18 @@ D_BUF dbuf;
 			for ( i = 0 ; i < DM_LIST_SIZE ; i ++ ) {
 				if ( dm_list[i] == 0 )
 					break;
-				dm_list[i]->flags &= ~DMF_LOADED;
+				dm_list[i]->flags &= ~(DMF_LOADED|DMF_HANDLING);
 			}
 			unlock_task(dm_lock,"dm_loading_task2");
 			d_f_ree(key);
 ss_printf("ERROR 2\n");
+print_sexp(s_stdout,pp,0);
+ss_printf("\n");
 			goto end;
 		}
 
+		reset_handle_dm_list(dm_list);
+
 		unlock_task(dm_lock,"dm_loading_task2");
 
 		/***/
@@ -613,11 +656,13 @@ ss_printf("ERROR 2\n");
 
 		insert_queue(&pipe2,n,1);
 
+
 	end:
 		gc_pop(0,0);
 	}
 	close_self_interpreter();
 	release_qkey(&pipe1,_key);
+	d_f_ree(_key);
 }
 
 int
@@ -809,7 +854,7 @@ max_size);
 #ifdef DRAW_DEBUG
 printf("query = ");
 fflush(stdout);
-print_sexp(s_stdout,query,0);
+print_sexp(s_stdout,query,PF_RAW_DISABLE);
 ss_printf("\n");
 #endif
 
@@ -874,10 +919,15 @@ int i;
 		}
 		if ( dm->level ) {
 			dm->flags |= DMF_LOADED;
+			dm->flags &= ~DMF_HANDLING;
+			reset_handle_dm_list(dm_list);
 			return 0;
 		}
-		if ( lev_min )
+		if ( lev_min ) {
+			dm->flags &= ~DMF_HANDLING;
+			reset_handle_dm_list(dm_list);
 			return 0;
+		}
 	}
 
 	gc_push(0,0,"loading_draw_tile");
@@ -923,7 +973,7 @@ rct->tl.x,rct->tl.y,
 rct->br.x,rct->br.y,
 rct->br.x - rct->tl.x,
 rct->br.y - rct->tl.y);
-print_sexp(s_stdout,query,0);
+print_sexp(s_stdout,query,PF_RAW_DISABLE);
 ss_printf("\n");
 #endif
 	set_inc_status(r,RS_LOAD);
@@ -1081,6 +1131,8 @@ int type;
 		n2->handle_time = dm->get_handle_time;
 		n2->h.key = get_server_key(&r->h.target,0);
 		n2->type = type;
+		dm->flags &= ~DMF_HANDLING;
+		set_handle_dm_list(n2->dm_list);
 
 		insert_queue(&pipe1,n2,1);
 	end:
@@ -1089,10 +1141,11 @@ int type;
 		if ( er == -2 )
 			dm->flags |= DMF_REQUEST;
 		if ( er < 0 ) {
+			dm->flags &= ~DMF_HANDLING;
 			for ( i = 0 ; i < DM_LIST_SIZE ; i ++ ) {
 				if ( n1->dm_list[i] == 0 )
 					break;
-				n1->dm_list[i]->flags &= ~DMF_LOADED;
+				n1->dm_list[i]->flags &= ~(DMF_LOADED|DMF_HANDLING);
 			}
 		}
 		unlock_task(dm_lock,"loading_draw");
@@ -1103,16 +1156,41 @@ int type;
 		gc_pop(0,0);
 	}
 	release_qkey(&pipe0,key);
+	d_f_ree(key);
 	
 	close_self_interpreter();
 }
 
+void
+reset_handle_dm_list(DRAW_MATRIX ** lst)
+{
+int i;
+	for ( i = 0 ; ; i ++ ) {
+		if ( lst[i] == 0 )
+			break;
+		lst[i]->flags &= ~DMF_HANDLING;
+	}
+}
+
+void
+set_handle_dm_list(DRAW_MATRIX ** lst)
+{
+int i;
+	for ( i = 0 ; ; i ++ ) {
+		if ( lst[i] == 0 )
+			break;
+		lst[i]->flags |= DMF_HANDLING;
+	}
+}
+
 int
 set_dm_list(DRAW_MATRIX ** list,int ptr,DRAW_MATRIX * dm)
 {
+	if ( dm->flags & DMF_DELETE )
+		return -1;
 	if ( dm->flags & DMF_LOADED )
 		return ptr;
-	dm->flags |= DMF_LOADED;
+	dm->flags |= DMF_LOADED|DMF_HANDLING;
 	list[ptr++] = dm;
 	return ptr;
 }
@@ -1136,13 +1214,13 @@ set_dm_ac(DRAW_MATRIX * dm)
 {
 	DELETE_RING(&dm->h);
 	INSERT_RING(&dm_h,&dm->h);
-	dm->access = get_ac_time();
+	dm->access = get_xltime();
 
 	dm = dm->parent;
 	for ( ; dm ; ) {
 		DELETE_RING(&dm->h);
 		INSERT_RING(&dm_h,&dm->h);
-		dm->access = get_ac_time();
+		dm->access = get_xltime();
 		dm = dm->parent;
 	}
 }
@@ -1162,22 +1240,24 @@ dm->r->draw_gb.pitch_list[dm->level+1].x,
 dm->r->draw_gb.level);
 */
 	lock_task(dm_lock);
+	if ( dm->flags & DMF_DELETE ) {
+		unlock_task(dm_lock,"");
+		return 0;
+	}
 	dm_list = d_alloc(sizeof(DRAW_MATRIX)*DM_LIST_SIZE);
 	for ( i = 0 ; i < DM_LIST_SIZE ; i ++ )
 		dm_list[i] = 0;
-	dm->flags &= ~DMF_REQUEST;
-	for ( dm2 = dm->parent ;
-			dm2 ; dm2 = dm2->parent ) {
-		dm2->flags &= ~DMF_REQUEST;
-		dm2->get_handle_time = 0;
-		dm2->get_level = 0;
-	}
 
 	dm_ptr = set_dm_list(dm_list,0,dm);
+	if ( dm_ptr < 0 ) {
+		reset_handle_dm_list(dm_list);
+		unlock_task(dm_lock,"");
+		d_f_ree(dm_list);
+		return 0;
+	}
 /*
 	set_dm_ac(dm);
 */
-	unlock_task(dm_lock,"load_dm");
 	pt.x = dm->ofs.x*
 		dm->r->draw_gb.pitch_list[dm->level].x;
 	pt.y = dm->ofs.y*
@@ -1196,13 +1276,24 @@ dm->r->draw_gb.level);
 		rct.tl.x = dm->r->h.minrect.tl.x;
 	if ( rct.tl.y < dm->r->h.minrect.tl.y )
 		rct.tl.y = dm->r->h.minrect.tl.y;
-	if ( rct.tl.x >= rct.br.x )
+	if ( rct.tl.x >= rct.br.x ){
+		unlock_task(dm_lock,"load_dm");
+		reset_handle_dm_list(dm_list);
+		d_f_ree(dm_list);
 		return 0;
-	if ( rct.tl.y >= rct.br.y )
+	}
+	if ( rct.tl.y >= rct.br.y ){
+		unlock_task(dm_lock,"load_dm");
+		reset_handle_dm_list(dm_list);
+		d_f_ree(dm_list);
 		return 0;
-	lock_task(dm_lock);
+	}
 	lev_min = dm->level;
 	lev_max = dm->level;
+
+
+
+
 	dm2 = dm;
 	dm = dm->parent;
 	for ( ; dm ; ) {
@@ -1210,11 +1301,29 @@ dm->r->draw_gb.level);
 			break;
 		lev_max = dm->level;
 		dm_ptr = check_loaded(dm,dm_list,dm_ptr);
+		if ( dm_ptr < 0 ) {
+			unlock_task(dm_lock,"load_dm");
+			reset_handle_dm_list(dm_list);
+			d_f_ree(dm_list);
+			return 0;
+		}
 		dm = dm->parent;
 	}
+	dm_list[dm_ptr] = 0;
+	dm2->flags |= DMF_HANDLING;
+
+	dm = dm2;
+	dm->flags &= ~DMF_REQUEST;
+	for ( dm2 = dm->parent ;
+			dm2 ; dm2 = dm2->parent ) {
+		dm2->flags &= ~DMF_REQUEST;
+		dm2->get_handle_time = 0;
+		dm2->get_level = 0;
+	}
+	dm2 = dm;
+
 	unlock_task(dm_lock,"load_dm");
 
-	dm_list[dm_ptr] = 0;
 	if ( dm2->r->draw_gb.type == DGT_PDB )
 		loading_draw(dm2,
 			lev_min,
@@ -1340,43 +1449,42 @@ DRAW_MATRIX * dm;
 	return get_next_dm1();
 }
 
+
+void
+dm_resource_scan_tick()
+{
+	wakeup_task((int)&dm_h);
+}
+
 void
 dm_scan_task()
 {
 DRAW_MATRIX * dm;
 XL_INTERPRETER * xli;
 int ses;
+INTEGER64 scan_tim;
 
-
-printf("dm_scan_task %i\n",get_tid());
-
+	new_tick((void(*)(int))dm_resource_scan_tick,5,0);
 
 	xli = new_xl_interpreter();
 	xli->a_type = XLA_SELF;
 	setup_i(xli);
 	ses = open_session(SEST_OPTIMIZE);
+	
+	scan_tim = get_xltime();
 
 	for ( ; ; ) {
 
-		lock_task(dm_lock);
-		if ( scan_flag ) {
-			scan_flag = 0;
-			unlock_task(dm_lock,"scan_required");
+		if ( get_xltime() - scan_tim > 5 ) {
 			dm_resource_scan();
-			wakeup_task((int)&scan_flag);
+			scan_tim = get_xltime();
 		}
-		else	unlock_task(dm_lock,"scan_required");
-
 
 		lock_task(dm_lock);
 		dm = get_next_dm();
 		if ( dm )
 			goto load;
 
-		if ( scan_flag ) {
-			unlock_task(dm_lock,"scan_Required");
-			continue;
-		}
 		gc_check_empty("dm_scan_task",0);
 
 		sleep_task((int)&dm_h,dm_lock);
@@ -1389,6 +1497,7 @@ printf("dm_scan_task %i\n",get_tid());
 }
 
 
+/*
 int
 dm_last_access(int * ret_p)
 {
@@ -1409,6 +1518,7 @@ end:
 	unlock_task(dm_lock,"digging");
 	return ret;
 }
+*/
 
 DRAW_MATRIX *
 new_draw_matrix(WF_ID wfid,RESOURCE * r,DRAW_MATRIX * dm,int x,int y)
@@ -1445,7 +1555,7 @@ int i,j;
 	dm1->flags = 0;
 	dm1->wfid = wfid;
 	dm1->loop_no = r->h.loop_no;
-	dm1->access = get_ac_time();
+	dm1->access = get_xltime();
 	dm_nos ++;
 	INSERT_RING(&dm_h,&dm1->h);
 	return dm1;
@@ -1471,7 +1581,7 @@ SI_GBVIEW g;
 
 	DELETE_RING(&dm->h);
 	INSERT_RING(&dm_h,&dm->h);
-	dm->access = get_ac_time();
+	dm->access = get_xltime();
 	dm->r = res;
 	dm->loop_no = res->h.loop_no;
 
