@@ -28,6 +28,10 @@
 #include	"mx_format.h"
 #include	"pg_vector.h"
 
+/*
+#define PGV_DEBUG
+*/
+
 
 #define PDB_RESO	1
 #define POINT_MIN_DIRECTION_STEP	4
@@ -1087,6 +1091,10 @@ int er_code;
 	for ( i = 0 ; i < dsize ; i ++ )
 		dw->pixels[i] = C_TRANSPARENT;
 
+#ifdef PGV_DEBUG
+ss_printf("=================== PG VECTOR\n");
+#endif
+
 	rp = get_surp_rect_rate(&rp_len,&dw->surp,0.1,0);
 	for ( rr = 0 ; rr < rp_len ; rr ++ )  {
 		if ( wf_active_check_2(gf,dw->wfid) < 0 )
@@ -1147,7 +1155,9 @@ int er_code;
 						&ix[0],vm->view_channel[0],
 						GN_TREE,GN_STEP_NODE_CREATE,0,r->h.loop_no);
 			}
-//ss_printf("PG PLOT CH %i = %p %p - LEVEL = %i\n",vm->view_channel[0],d,n,lev);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT CH %i = %p %p - LEVEL = %i\n",vm->view_channel[0],d,n,lev);
+#endif
 			if ( n == 0 ) 
 				goto last;
 			if ( d == 0 )
@@ -1155,22 +1165,31 @@ int er_code;
 			(*n->channel[vm->view_channel[0]].sb->tbl->operation)(PPC_GET,
 				n->channel[vm->view_channel[0]].sb,&ip);
 
-//ss_printf("PG PLOT IP = %p\n",ip);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT IP = %p\n",ip);
+#endif
+
 			get_target_plot(&ip_list,&ip_pt_list,&ip_reso_list,&ip_flags_list,&b_size,&size,n,ip,rct,r->pr64.dpm);
 			map_conv_forward(dw->map->map_file,ip_pt_list,ip_reso_list,size);
 			map_from_resource(dw->mh,ip_pt_list,ip_reso_list,size);
 			
-//ss_printf("PG PLOT size = %p\n",size);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT size = %p\n",size);
+#endif
 			ip_p = ip_list;
 			ptr_p = ip_pt_list;
 			reso_p = ip_reso_list;
 			flags_p = ip_flags_list;
 			memset(flags_p,0,size);
 			for ( i = 0 ; i < size ; i ++, ip_p ++, ptr_p ++,reso_p++ , flags_p ++ ) {
-//ss_printf("PG PLOT DIST %i\n",(*ip_p)->min_direction);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT DIST %i\n",(*ip_p)->min_direction);
+#endif
 				if ( (*ip_p)->min_direction < POINT_MIN_DIRECTION_STEP ) {
 				plot_color:
-//ss_printf("PG PLOT COLOR-1\n");
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT COLOR-1\n");
+#endif
 					dw->flags |= WFF_POLY; 
 					if ( dw->pixels == 0 )
 						continue;
@@ -1179,7 +1198,9 @@ int er_code;
 					index = ((int)(ptr_p->x - dw->rectondisp->tl.x)) +
 							((int)(ptr_p->y - dw->rectondisp->tl.y)) *
 							width;
-//ss_printf("PG PLOT COLOR-2 %i %i - %i %x\n",(*ip_p)->c[0],(*ip_p)->c[1],vmp->color_field,vmp->default_color);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT COLOR-2 %i %i - %i %x\n",(*ip_p)->c[0],(*ip_p)->c[1],vmp->color_field,vmp->default_color);
+#endif
 					if ( vmp->color_field >= 0 ) {
 						if ( vmp->color_field >= (*ip_p)->fields[0].len )
 							continue;
@@ -1194,7 +1215,9 @@ int er_code;
 					else	dw->pixels[index] = convert_rgba_to_cc(vmp->default_color);
 				}
 				else {
-//ss_printf("PG PLOT LOGO-1\n");
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT LOGO-1\n");
+#endif
 					logo = (*ip_p)->min_direction / POINT_MIN_DIRECTION_STEP;
 					if ( get_logo_info(vmp,*ip_p,logo,&logo_url,&logo_align,&logo_offset,&logo_t_color,
 							&logo_anchor) < 0 )
@@ -1273,15 +1296,23 @@ int er_code;
 				}
 
 				if ( /* size > STRING_ALL_PRINT &&*/ (*flags_p) )
-{//ss_printf("PG PLOT ONMAP-0\n");
+{
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT ONMAP-0\n");
+#endif
 					continue;
 }
 				if ( (*ip_p)->flags & PP_MERGED_FIELDS )
-{//ss_printf("PG PLOT ONMAP-MERGE %p\n",(*ip_p)->base);
+{
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT ONMAP-MERGE %p\n",(*ip_p)->base);
+#endif
 					continue;
 }
 				if ( (*ip_p)->onmap == 0 ) {
+#ifdef PGV_DEBUG
 ss_printf("PG PLOT ONMAP-1\n");
+#endif
 
 					ac = get_arg_cache(vmp,*ip_p);
 					if ( ac->onmap == 0  ) {
@@ -1290,25 +1321,25 @@ ss_printf("PG PLOT ONMAP-1\n");
 						XL_SEXP * data;
 						XL_SEXP * sym;
 						int list_f;
-/*
+#ifdef PGV_DEBUG
 ss_printf("PG PLOT ONMAP-2 %i\n",vmp->direct_onmap_field);
-*/
+#endif
 							list_f = 0;
 							gc_push(0,0,"onmap");
 							if ( vmp->direct_onmap_field >= 
 									(*ip_p)->fields[0].len )
 								goto ac_error;
 							fd = &(*ip_p)->fields[vmp->direct_onmap_field];
-/*
+#ifdef PGV_DEBUG
 ss_printf("PG PLOT ONMAP-3 %x %x\n",fd->type,CH_STRING);
-*/
+#endif
 							switch ( fd->type ) {
 							case CH_STRING:
 								data = get_string(
 									l_string(&utf8_cm,fd->d.str));
-/*
+#ifdef PGV_DEBUG
 ss_printf("DATA %x %x :: %x\n",fd->d.str[0],fd->d.str[1],data->string.data[0]);
-*/
+#endif
 								break;
 							case CH_INT_ADD:
 							case CH_INT_AVG:
@@ -1367,9 +1398,9 @@ ss_printf("DATA %x %x :: %x\n",fd->d.str[0],fd->d.str[1],data->string.data[0]);
 							s = eval(env,(XL_SEXP*)vmp->ind_convert->data);
 							er_code = 1;
 							if ( get_type(s) != XLT_ERROR ) {
-/*
+#ifdef PGV_DEBUG
 ss_printf("PG PLOT ONMAP-2-1\n");
-*/
+#endif
 								er_code = 2;
 								s = get_onmap_info(r,vmp->ischeme,s,&style_reso);
 								if ( get_type(s) != XLT_ERROR ) {
@@ -1411,7 +1442,9 @@ ss_printf("PG PLOT ONMAP-2-1\n");
 */
 					}
 					else {
-//ss_printf("PG PLOT ONMAP-3\n");
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT ONMAP-3\n");
+#endif
 						if ( ac->onmap )
 							(*ip_p)->onmap = new_matrix_sexp(ac->onmap->data);
 /*
@@ -1423,17 +1456,21 @@ ss_printf("PG PLOT ONMAP-2-1\n");
 				if ( (*ip_p)->id == 0 ) {
 					er_panic("obj*id");
 				}
-//ss_printf("PG PLOT ONMAP-5 %p %p\n",(*ip_p)->onmap,(*ip_p)->card);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT ONMAP-5 %p %p\n",(*ip_p)->onmap,(*ip_p)->card);
+#endif
 				if ( (*ip_p)->onmap == 0 )
 					continue;
-//ss_printf("PG PLOT ONMAP-5-1\n");
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT ONMAP-5-1\n");
+#endif
 				if ( (*ip_p)->onmap->data == 0 )
 					continue;
-/*
+#ifdef PGV_DEBUG
 ss_printf("PG PLOT ONMAP-6\n");
 print_sexp(s_stdout,(*ip_p)->onmap->data,0);
 ss_printf("\n");
-*/
+#endif
 				pic = get_onmap_string_pic(gf,(*ip_p)->onmap->data);
 				if ( pic.list == 0 ){
 					free_pic(pic);
@@ -1484,7 +1521,9 @@ ss_printf("\n");
 						flags = SIF_ANCOR;
 					else	flags = 0;
 
-//ss_printf("PG PLOT ONMAP-7 REF=%p %x\n",pe->ref,flags);
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT ONMAP-7 REF=%p %x\n",pe->ref,flags);
+#endif
 					wf_insert_si(
 						gf,
 						ISI_INSERT,
