@@ -118,7 +118,7 @@ typedef struct gbview_flame {
 
 #define ZONBIE_CHECK(gf,func,ret)	\
 	if ( (gf)->status & GVFM_ZONBIE ) {	\
-		func(gf);			\
+		(func);			\
 		return (ret);			\
 	}
 #define ZONBIE_CHECK_VOID(gf,func)	\
@@ -154,6 +154,10 @@ typedef struct gbview_flame {
 	REAL1			flame_base_rotate;
 	REAL1			flame_base_resolution;
 	MAP_HISTORY		flame_base_display_map;
+	int			flame_base_geo_type;
+	
+	int			flame_base_y_offset;
+		/* for e1d :: y coordinate on the WIN of [top of first wf base] computer axis*/
 	SELECT_INDICATE * si;
 	char *		redraw;
 #define RP_REDRAW		1
@@ -208,10 +212,14 @@ typedef struct gbview_flame {
 	int		indicate_req;
 	int		indicate_task_active;
 	int		raw_image_request;
+	
+	INTEGER64	move_timer;
 
 	int		zonbie_timeout;
 
 	unsigned	move_flag:1;
+	unsigned	redraw_delay_flag:1;
+	unsigned	redrow_flag:1;
 	
 	struct gbview_flame *	next;
 } GBVIEW_FLAME;
@@ -265,16 +273,17 @@ typedef struct gbview_status {
 #define SF_ROTATE	0x10000000
 #define SF_UNIT		0x08000000
 #define SF_MAP_TYPE	0x04000000
-#define SF_PP_RADIUS	0x02000000
-#define SF_REFERENCE	0x01000000
-#define SF_RADAR	0x00800000
+#define SF_GEO_TYPE	0x02000000
+#define SF_PP_RADIUS	0x01000000
+#define SF_REFERENCE	0x00800000
+#define SF_RADAR	0x00400000
 
-#define SF_DONT_SEQ	0x00400000
+#define SF_DONT_SEQ	0x00200000
 
 #define SF_BASE		0x00001fff
-#define SF_ALL		0xfc001fff
+#define SF_ALL		0xffe01fff
 
-#define SF_LAYER_DETAILS 0x00400000
+#define SF_LAYER_DETAILS 0x00100000
 
 	int		status;
 	int		layer_nos;
@@ -285,6 +294,8 @@ typedef struct gbview_status {
 	REAL1		flame_base_rotate;
 	L_CHAR *	flame_base_unit;
 	int		flame_base_display_map_type;
+	int		flame_base_geo_type;
+
 	INDICATE *	indicate;
 	INFO_LIST *	infolist;
 	void		(*event)(struct gbview_flame*,int,void*,void*);
@@ -409,7 +420,8 @@ int cache_image(
 	MAP_HISTORY *mh,
 	SURP_SET * surp,
 	int methd,
-	int flags);
+	int flags,
+	void * dw_work);
 
 
 int wf_redraw(GBVIEW_FLAME * gf,GBVIEW_PLANE * p,int x,int y,int w,int h);
@@ -439,7 +451,12 @@ int wf_goto_point(
 	L_CHAR * url,
 	GB_POINT ptr,
 	REAL1 rotate,
-	REAL1 reso);
+	REAL1 reso,
+	int flags);
+
+#define GP_IGN_PTR	0x00000001
+#define GP_IGN_ROTATE	0x00000002
+#define GP_IGN_RESO	0x00000004
 
 
 
@@ -465,8 +482,8 @@ void *
 get_ri(int * w,int * h,GBVIEW_FLAME * gf,WF_ID req,L_CHAR * path);
 int free_object(RESOURCE*,OBJ*);
 void free_object_list(RESOURCE*);
-XL_SEXP * get_card_info(RESOURCE * r,XL_SEXP * org);
-XL_SEXP * get_onmap_info(RESOURCE * r,XL_SEXP * org,REAL1 * reso);
+XL_SEXP * get_card_info(RESOURCE * r,INFO_SCHEME *,XL_SEXP * org);
+XL_SEXP * get_onmap_info(RESOURCE * r,INFO_SCHEME *,XL_SEXP * org,REAL1 * reso);
 PIC get_onmap_string_pic(GBVIEW_FLAME * gf,XL_SEXP*);
 void test_draw_object(RESOURCE * r);
 
@@ -941,9 +958,9 @@ XL_SEXP * get_xl_env(XL_SEXP * style);
 void fetch_style_file(int ses,STYLE_FILE * sf);
 STYLE_FILE *search_style_file(L_CHAR * name,int type,int wait_flag);
 INFO_SCHEME *search_scheme(INFO_SCHEME * is,L_CHAR * scheme);
-STYLE_FILE *get_info_style(RESOURCE * r,L_CHAR * scheme,int type,int wait_flag);
+STYLE_FILE *get_info_style(INFO_SCHEME * is_org,L_CHAR * scheme,int type,int wait_flag);
 void setup_onmap_env(RESOURCE * r,XLISP_ENV * env);
-XL_SEXP * _get_styled_info(RESOURCE * r,int type,XL_SEXP * org,REAL1 * reso);
+XL_SEXP * _get_styled_info(RESOURCE * r,INFO_SCHEME*is_org,int type,XL_SEXP * org,REAL1 * reso);
 void style_load_task();
 
 char * skip_space(char * p);
@@ -987,6 +1004,28 @@ int
 get_object_minrect2(GB_RECT * rct,RESOURCE * r,unsigned int code);
 void *
 get_from_network(XL_SEXP ** err,int ses,int * size,L_CHAR * path);
+int
+set_hwf(int d,int save_flag);
+int
+set_draw_mapping(int d,int save_flag);
+unsigned long
+convert_rgba_to_cc(unsigned int cc);
+void
+_wf_set_delay_redraw_exec(GBVIEW_FLAME * gf);
+void
+wf_set_delay_redraw_exec(GBVIEW_FLAME * gf);
+void
+_wf_set_delay_redraw(GBVIEW_FLAME * gf);
+void
+wf_set_delay_redraw(GBVIEW_FLAME * gf);
+void
+wf_set_delay_redraw_flag(GBVIEW_FLAME * gf,int fg);
+void
+_wf_set_delay_redraw_flag(GBVIEW_FLAME * gf,int fg);
+void
+wf_mouse_mode(GBVIEW_FLAME * gf,int mode,I_POINT ptr,INTEGER64 tim);
+
+
 
 extern XLISP_ENV * vector_env;
 
