@@ -58,6 +58,11 @@ typedef struct r_point {
 	REAL1	y;
 } R_POINT;
 
+typedef struct r_point_f {
+	float	x;
+	float	y;
+} R_POINT_F;
+
 typedef struct r_point3d {
 	REAL1	x;
 	REAL1	y;
@@ -69,6 +74,11 @@ typedef struct r_rect {
 	R_POINT		br;
 } R_RECT;
 
+typedef struct r_rect_f {
+	R_POINT_F	tl;
+	R_POINT_F	br;
+} R_RECT_F;
+
 #define COL_BIT			10
 #define COL_MASK		0x3ff
 
