@@ -405,12 +405,12 @@ XL_INTERPRETER * xli;
 		}
 
 		q = ft2_task_queue;
+		ft2_task_queue = q->next;
+		if ( ft2_task_queue == 0 )
+			ft2_task_queue_last = 0;
 
 		q->ret = (*q->func)(q->arg);
 
-		if ( q == ft2_task_queue_last )
-			ft2_task_queue_last = 0;
-		ft2_task_queue = q->next;
 		wakeup_task((int)q);
 	}
 }
@@ -425,13 +425,16 @@ struct ft2_task_queue_t *n;
 	n = (struct ft2_task_queue_t*)d_alloc(sizeof(*n));
 	n->func = func;
 	n->arg = arg;
-	n->next = ft2_task_queue_last;
+	n->next = 0;
 	n->ret = 0x7fffffff;
 	n->file = _file;
 	n->line = _line;
-	if ( ft2_task_queue == 0 )
-		ft2_task_queue = n;
-	ft2_task_queue_last = n;
+	if ( ft2_task_queue_last == 0 )
+		ft2_task_queue = ft2_task_queue_last = n;
+	else {
+		ft2_task_queue_last->next = n;
+		ft2_task_queue_last = n;
+	}
 
 	wakeup_task((int)&ft2_task_queue);
 	for ( ; n->ret == 0x7fffffff ; ) {
@@ -973,6 +976,14 @@ struct ft2_font_coverage_t arg;
 int ch_i,ch_j;
 char * c;
 FT2_ENCODE_INFO * ei;
+
+/*
+	if ( ch >= 0x100 )
+		return -1;
+	if ( LCZ_2BC_UNICODE_v1_1_JP <= ch && ch <= (LCZ_2BC_UNICODE_v3_0_UN_CN+0xffff) )
+		return -1;
+*/
+
 	for ( i = 0 ; i < f->fw_len ; i ++ )
 		if ( f->fw_list[i].fe->type == &ft2_font_engine_type )
 			break;
