@@ -36,10 +36,16 @@ char * _f;
 		goto end;
 	}
 	p = d_alloc(sizeof(*p));
+	memset(p,0,sizeof(*p));
 	p->fid = fid;
 	p->oflags = oflags;
 	p->flags = flags;
-	u_lseek(fid,0,SEEK_SET);
+
+	p->fac.fd = fid;
+	p->fac.long_file = 1;
+	fac_init(&p->fac);
+
+	fac_lseek(&p->fac,0,SEEK_SET);
 	p->fofs = 0;
 /*
 	p->request = 0;
