@@ -133,6 +133,7 @@ insert_favt_ring(FAVT_HEADER * h)
 	h->next = favt_h.next;
 	h->prev->next = h;
 	h->next->prev = h;
+	h->access_time = get_xltime();
 	favt_count ++;
 }
 
@@ -400,6 +401,8 @@ clear_cache()
 FAVT_NODE * n;
 FAVT_ROOT * r;
 FAVT_HEADER * h, * h2;
+INTEGER64 now;
+	now = get_xltime();
 	for ( ; favt_count > FAVT_CACHE_SIZE ; ) {
 		for ( h = favt_h.prev ; h != &favt_h ; ) {
 			if ( h->flags & FAF_LOCK ) {
@@ -428,10 +431,14 @@ FAVT_HEADER * h, * h2;
 			default:
 				er_panic("clear_cache");
 			}
+			if ( now - h->access_time < FAVT_CACHE_LIFE ) {
+				h = h->prev;
+				continue;
+			}
 			break;
 		}
 		if ( h == &favt_h )
-			er_panic("clear_cache");
+			break;
 		if ( check_dirty(h,0) ) {
 			for ( h2 = favt_h.next ; h2 != &favt_h ; 
 					h2 = h2->next )
