@@ -150,7 +150,7 @@ KEY_LIST * k;
 		if ( l_strcmp(k->key,key) == 0 ) {
 			if ( wait_flag < Q_WAIT_FORCE_INSERT &&
 			    		q->key_limit && 
-					k->cnt >= q->key_limit )
+					k->cnt >= k->limit )
 				return -1;
 			k->cnt ++;
 			return 0;
@@ -159,6 +159,7 @@ KEY_LIST * k;
 
 	k->key = ll_copy_str(key);
 	k->cnt = 1;
+	k->limit = q->key_limit;
 	k->task_asign = 0;
 
 	k->next = q->keylist;
@@ -652,6 +653,40 @@ int ret;
 	return ret;
 }
 
+int set_key_limit(SYS_QUEUE * q,L_CHAR * key,float limit)
+{
+KEY_LIST * k;
+int ret;
+	ret = -1;
+	lock_task(*q->target_lock);
+	for ( k = q->keylist ; k ; k = k->next ) {
+		if ( l_strcmp(k->key,key) )
+			continue;
+		k->limit = limit;
+		ret = 0;
+		break;
+	}
+	unlock_task(*q->target_lock,"set_key_liimit");
+	return ret;
+}
+
+
+
+float get_key_limit(SYS_QUEUE * q,L_CHAR * key)
+{
+KEY_LIST * k;
+float ret;
+	ret = q->key_limit;
+	lock_task(*q->target_lock);
+	for ( k = q->keylist ; k ; k = k->next ) {
+		if ( l_strcmp(k->key,key) )
+			continue;
+		ret = k->limit;
+		break;
+	}
+	unlock_task(*q->target_lock,"set_key_liimit");
+	return ret;
+}
 
 int
 _wait_queue_total_cnt(SYS_QUEUE * q,int size,int type_flags)
