@@ -248,7 +248,10 @@ int flags;
 	else
 		flags = 0;
 
-	img = get_image_from_sf(&img_ret,env,arg->h.file->name,sf);
+	if ( arg->h.file )
+		img = get_image_from_sf(&img_ret,env,arg->h.file->name,sf);
+	else	img = get_image_from_sf(&img_ret,env,0,sf);
+	
 	if ( img == 0 ) {
 		return vobj_get_error(initial_VExError(V_ER_PARAM,0,0),arg,0);
 	}
